@@ -1,9 +1,15 @@
 #!/usr/bin/perl -w
 
-# tailbot
-#
-# from the fbi bot by richardc, tails a file called 'logfile' to the channel
-# #tailbot.
+=head1 NAME
+
+tailbot
+
+=head1 DESCRIPTION
+
+from the fbi bot by richardc, tails a file called 'logfile' to the channel
+#tailbot.
+
+=cut
 
 use strict;
 use base 'Bot::BasicBot';
@@ -11,6 +17,7 @@ use base 'Bot::BasicBot';
 sub connected {
     my $self = shift;
 
+    # voodoo
     $self->forkit({ channel => '#tailbot',
                     run     => [ qw ( /usr/bin/tail -f logfile ) ] });
 }
